@@ -8,7 +8,15 @@ class NameCollector(CodeGenerator):
     """
 
     logger = logging.getLogger('pyprotobuf.NameCollector')
-    
+
+    def visit_EnumNode(self, node):
+        self.logger.debug('Adding enum %s', node.get_full_name())
+
+        # add the enumerations to the global scope
+        for child in node.children:
+            self.frame.add_to_globals(child.get_full_name(), child)
+
+
     def visit_MessageNode(self, node):
         self.logger.debug('Adding message %s', node.get_full_name())
         self.frame.add_node(node)
\ No newline at end of file
